@@ -82,9 +82,12 @@ class QRCodeAdmin(admin.ModelAdmin):
 
     def formfield_for_foreignkey(self, db_field, request, **kwargs):
         if db_field.name == 'department' and not request.user.is_superuser:
-            kwargs['queryset'] = request.user.departments.first()
+            kwargs['queryset'] = request.user.departments.all()
         return super(QRCodeAdmin, self).formfield_for_foreignkey(db_field, request, **kwargs)
 
+    def get_changeform_initial_data(self, request):
+        return {'department': request.user.departments.first()}
+
     def get_urls(self):
         urls = super(QRCodeAdmin, self).get_urls()
         custom_urls = [
